==> aws-java-sdk-dynamodb-1.10.61-sources.jar: com/amazonaws/services/dynamodbv2/model/transform/CreateGlobalSecondaryIndexActionJsonUnmarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.dynamodbv2.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import com.amazonaws.services.dynamodbv2.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;

import com.fasterxml.jackson.core.JsonToken;
import static com.fasterxml.jackson.core.JsonToken.*;

/**
 * CreateGlobalSecondaryIndexAction JSON Unmarshaller
 */
public class CreateGlobalSecondaryIndexActionJsonUnmarshaller implements
        Unmarshaller<CreateGlobalSecondaryIndexAction, JsonUnmarshallerContext> {

    public CreateGlobalSecondaryIndexAction unmarshall(
            JsonUnmarshallerContext context) throws Exception {
        CreateGlobalSecondaryIndexAction createGlobalSecondaryIndexAction = new CreateGlobalSecondaryIndexAction();

        int originalDepth = context.getCurrentDepth();
        String currentParentElement = context.getCurrentParentElement();
        int targetDepth = originalDepth + 1;

        JsonToken token = context.getCurrentToken();
        if (token == null)
            token = context.nextToken();
        if (token == VALUE_NULL)
            return null;

        while (true) {
            if (token == null)
                break;

            if (token == FIELD_NAME || token == START_OBJECT) {
                if (context.testExpression("IndexName", targetDepth)) {
                    context.nextToken();
                    createGlobalSecondaryIndexAction
                            .setIndexName(StringJsonUnmarshaller.getInstance()
                                    .unmarshall(context));
                }
                if (context.testExpression("KeySchema", targetDepth)) {
                    context.nextToken();
                    createGlobalSecondaryIndexAction
                            .setKeySchema(new ListUnmarshaller<KeySchemaElement>(
                                    KeySchemaElementJsonUnmarshaller
                                            .getInstance()).unmarshall(context));
                }
                if (context.testExpression("Projection", targetDepth)) {
                    context.nextToken();
                    createGlobalSecondaryIndexAction
                            .setProjection(ProjectionJsonUnmarshaller
                                    .getInstance().unmarshall(context));
                }
                if (context
                        .testExpression("ProvisionedThroughput", targetDepth)) {
                    context.nextToken();
                    createGlobalSecondaryIndexAction
                            .setProvisionedThroughput(ProvisionedThroughputJsonUnmarshaller
                                    .getInstance().unmarshall(context));
                }
            } else if (token == END_ARRAY || token == END_OBJECT) {
                if (context.getLastParsedParentElement() == null
                        || context.getLastParsedParentElement().equals(
                                currentParentElement)) {
                    if (context.getCurrentDepth() <= originalDepth)
                        break;
                }
            }
            token = context.nextToken();
        }

        return createGlobalSecondaryIndexAction;
    }

    private static CreateGlobalSecondaryIndexActionJsonUnmarshaller instance;

    public static CreateGlobalSecondaryIndexActionJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new CreateGlobalSecondaryIndexActionJsonUnmarshaller();
        return instance;
    }
}

==> aws-java-sdk-dynamodb-1.11.18-sources.jar: com/amazonaws/services/dynamodbv2/model/transform/CreateGlobalSecondaryIndexActionJsonUnmarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.dynamodbv2.model.transform;

import java.util.Map;
import java.util.Map.Entry;
import java.math.*;
import java.nio.ByteBuffer;

import com.amazonaws.services.dynamodbv2.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;

import com.fasterxml.jackson.core.JsonToken;
import static com.fasterxml.jackson.core.JsonToken.*;

/**
 * CreateGlobalSecondaryIndexAction JSON Unmarshaller
 */
public class CreateGlobalSecondaryIndexActionJsonUnmarshaller implements
        Unmarshaller<CreateGlobalSecondaryIndexAction, JsonUnmarshallerContext> {

    public CreateGlobalSecondaryIndexAction unmarshall(
            JsonUnmarshallerContext context) throws Exception {
        CreateGlobalSecondaryIndexAction createGlobalSecondaryIndexAction = new CreateGlobalSecondaryIndexAction();

        int originalDepth = context.getCurrentDepth();
        String currentParentElement = context.getCurrentParentElement();
        int targetDepth = originalDepth + 1;

        JsonToken token = context.getCurrentToken();
        if (token == null)
            token = context.nextToken();
        if (token == VALUE_NULL)
            return null;

        while (true) {
            if (token == null)
                break;

            if (token == FIELD_NAME || token == START_OBJECT) {
                if (context.testExpression("IndexName", targetDepth)) {
                    context.nextToken();
                    createGlobalSecondaryIndexAction.setIndexName(context
                            .getUnmarshaller(String.class).unmarshall(context));
                }
                if (context.testExpression("KeySchema", targetDepth)) {
                    context.nextToken();
                    createGlobalSecondaryIndexAction
                            .setKeySchema(new ListUnmarshaller<KeySchemaElement>(
                                    KeySchemaElementJsonUnmarshaller
                                            .getInstance()).unmarshall(context));
                }
                if (context.testExpression("Projection", targetDepth)) {
                    context.nextToken();
                    createGlobalSecondaryIndexAction
                            .setProjection(ProjectionJsonUnmarshaller
                                    .getInstance().unmarshall(context));
                }
                if (context
                        .testExpression("ProvisionedThroughput", targetDepth)) {
                    context.nextToken();
                    createGlobalSecondaryIndexAction
                            .setProvisionedThroughput(ProvisionedThroughputJsonUnmarshaller
                                    .getInstance().unmarshall(context));
                }
            } else if (token == END_ARRAY || token == END_OBJECT) {
                if (context.getLastParsedParentElement() == null
                        || context.getLastParsedParentElement().equals(
                                currentParentElement)) {
                    if (context.getCurrentDepth() <= originalDepth)
                        break;
                }
            }
            token = context.nextToken();
        }

        return createGlobalSecondaryIndexAction;
    }

    private static CreateGlobalSecondaryIndexActionJsonUnmarshaller instance;

    public static CreateGlobalSecondaryIndexActionJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new CreateGlobalSecondaryIndexActionJsonUnmarshaller();
        return instance;
    }
}
